#!/usr/local/bin/python3

# 2019-02-05  Delete troubleshooting tests for shell return code & stdout.
# 2019-02-04  Get status to verify track 1 both selected & playing.
# 2019-01-16  HQP_start_streaming.py

# Please edit the 2 IP addresses below.
# Use "localhost" for both if this program and HQPlayer are on same computer.

hqpRemoteIP = "10.0.4.5"
thisIP = "10.0.4.6"


# Program starts here; do not edit unless you know what you're doing:

import logging
import subprocess

log_file_path = '/usr/local/hqp_liquidsoap/log/HQP_start_streaming.log'

logging.basicConfig(format='%(asctime)s %(levelname)8s %(message)s',
                    filename=log_file_path, filemode='a+')


def tellHQP(cmd):
    for n in range(4):
        cmd_list = cmd.split()
        hq_shell_cmd = ["/Applications/HQPlayerDesktop.app/Contents/MacOS/hqp-control", hqpRemoteIP] + cmd_list
        hq_result = subprocess.run(hq_shell_cmd, capture_output=True, text=True)
        hq_return_code_n = hq_result.returncode
        if hq_return_code_n == 0:
            break  # HQP responded successfully, so exit loop.
        # print(cmd, 'failed', n + 1, 'times.')
        logging.warning(' %s failed %i times.', cmd, n+1)
    hq_stderr = hq_result.stderr
    return hq_stderr


def playTrackN(tkN):
    for n in range(4):
        tellHQP('--select-track ' + str(tkN))
        tellHQP('--play')
        hqStatus = tellHQP('--get-status')
        hqStatusList = hqStatus.split()
        stopPausePlay = hqStatusList[1]
        selectedTrackN = hqStatusList[2]
        min_colon_sec = hqStatusList[3]
        # print (str(n) +'   '+ stopPausePlay +'   '+ selectedTrackN +'   '+ min_colon_sec)
        # If HQP plays w/o track being selected, there's no sound.
        if (stopPausePlay == '2') and (selectedTrackN == str(tkN)):
            break


def main():
    logging.warning("Triggered Python script to start HQP.")

    stream_URL = "http://" + thisIP + ":8000/mystream"

    # Play immediately unless track 1 = file & paused:
    playTrackN(1)

    # Check whether file tracks in playlist,
    # hence playing wrong track!
    playlist_txt = tellHQP("--playlist-get")

    if playlist_txt.startswith('[1] ' + stream_URL + ' {}'):
        # If first track is stream, we're already playing it:
        playTrackN(1)
        tellHQP('--playlist-clear')
    else:
        if playlist_txt != '':
            # Non-empty playlist means we've been
            # erroneously playing a pre-existing file:
            tellHQP('--stop')
            tellHQP('--playlist-clear')

        # Playlist now is empty, so add stream and play it:
        tellHQP(stream_URL)
        playTrackN(1)
        tellHQP('--playlist-clear')
            

main()
